@@ -8,6 +8,7 @@ import (
 	"github.com/superfly/flyctl/client"
 	"github.com/superfly/flyctl/internal/app"
 	"github.com/superfly/flyctl/internal/command"
+	"github.com/superfly/flyctl/internal/command/orgs"
 	"github.com/superfly/flyctl/internal/flag"
 )
 
@@ -23,6 +24,11 @@ func newAllocatev4() *cobra.Command {
 	)
 
 	flag.Add(cmd,
+		flag.Bool{
+			Name:        "shared",
+			Description: "Allocates a shared IPv4",
+			Default:     false,
+		},
 		flag.App(),
 		flag.AppConfig(),
 		flag.Region(),
@@ -49,30 +55,57 @@ func newAllocatev6() *cobra.Command {
 			Name:        "private",
 			Description: "Allocate a private IPv6 address",
 		},
+		flag.Org(),
 	)
 
 	return cmd
 }
 
 func runAllocateIPAddressV4(ctx context.Context) error {
-	return runAllocateIPAddress(ctx, "v4")
+	addrType := "v4"
+	if flag.GetBool(ctx, "shared") {
+		addrType = "shared_v4"
+	}
+	return runAllocateIPAddress(ctx, addrType, nil)
 }
 
-func runAllocateIPAddressV6(ctx context.Context) error {
+func runAllocateIPAddressV6(ctx context.Context) (err error) {
 	private := flag.GetBool(ctx, "private")
 	if private {
-		return runAllocateIPAddress(ctx, "private_v6")
+		orgSlug := flag.GetOrg(ctx)
+		var org *api.Organization
+
+		if orgSlug != "" {
+			org, err = orgs.OrgFromSlug(ctx, orgSlug)
+			if err != nil {
+				return err
+			}
+		}
+		return runAllocateIPAddress(ctx, "private_v6", org)
 	}
-	return runAllocateIPAddress(ctx, "v6")
+
+	return runAllocateIPAddress(ctx, "v6", nil)
 }
 
-func runAllocateIPAddress(ctx context.Context, addrType string) error {
+func runAllocateIPAddress(ctx context.Context, addrType string, org *api.Organization) (err error) {
 	client := client.FromContext(ctx).API()
 
 	appName := app.NameFromContext(ctx)
+
+	if addrType == "shared_v4" {
+		ip, err := client.AllocateSharedIPAddress(ctx, appName)
+		if err != nil {
+			return err
+		}
+
+		renderSharedTable(ctx, ip)
+
+		return nil
+	}
+
 	region := flag.GetRegion(ctx)
 
-	ipAddress, err := client.AllocateIPAddress(ctx, appName, addrType, region)
+	ipAddress, err := client.AllocateIPAddress(ctx, appName, addrType, region, org)
 	if err != nil {
 		return err
 	}
