@@ -1,9 +1,11 @@
 package scanner
 
-import "github.com/superfly/flyctl/helpers"
+import (
+	"github.com/superfly/flyctl/helpers"
+)
 
 // setup django with a postgres database
-func configureDjango(sourceDir string) (*SourceInfo, error) {
+func configureDjango(sourceDir string, config *ScannerConfig) (*SourceInfo, error) {
 	if !checksPass(sourceDir, dirContains("requirements.txt", "Django")) {
 		return nil, nil
 	}
